==> vtk-8.1.0-6-armv6h.pkg.tar.xz: vtk/vtkSelectionNode.java <==
// java wrapper for vtkSelectionNode object
//

package vtk;
import vtk.*;

public class vtkSelectionNode extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native void SetSelectionList_3(vtkAbstractArray id0);
  public void SetSelectionList(vtkAbstractArray id0)
    { SetSelectionList_3(id0); }

  private native long GetSelectionList_4();
  public vtkAbstractArray GetSelectionList() {
    long temp = GetSelectionList_4();

    if (temp == 0) return null;
    return (vtkAbstractArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionData_5(vtkDataSetAttributes id0);
  public void SetSelectionData(vtkDataSetAttributes id0)
    { SetSelectionData_5(id0); }

  private native long GetSelectionData_6();
  public vtkDataSetAttributes GetSelectionData() {
    long temp = GetSelectionData_6();

    if (temp == 0) return null;
    return (vtkDataSetAttributes)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetProperties_7();
  public vtkInformation GetProperties() {
    long temp = GetProperties_7();

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void DeepCopy_8(vtkSelectionNode id0);
  public void DeepCopy(vtkSelectionNode id0)
    { DeepCopy_8(id0); }

  private native void ShallowCopy_9(vtkSelectionNode id0);
  public void ShallowCopy(vtkSelectionNode id0)
    { ShallowCopy_9(id0); }

  private native int GetMTime_10();
  public int GetMTime()
    { return GetMTime_10(); }

  private native long CONTENT_TYPE_11();
  public vtkInformationIntegerKey CONTENT_TYPE() {
    long temp = CONTENT_TYPE_11();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetContentType_12(int id0);
  public void SetContentType(int id0)
    { SetContentType_12(id0); }

  private native int GetContentType_13();
  public int GetContentType()
    { return GetContentType_13(); }

  private native long FIELD_TYPE_14();
  public vtkInformationIntegerKey FIELD_TYPE() {
    long temp = FIELD_TYPE_14();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFieldType_15(int id0);
  public void SetFieldType(int id0)
    { SetFieldType_15(id0); }

  private native int GetFieldType_16();
  public int GetFieldType()
    { return GetFieldType_16(); }

  private native int ConvertSelectionFieldToAttributeType_17(int id0);
  public int ConvertSelectionFieldToAttributeType(int id0)
    { return ConvertSelectionFieldToAttributeType_17(id0); }

  private native int ConvertAttributeTypeToSelectionField_18(int id0);
  public int ConvertAttributeTypeToSelectionField(int id0)
    { return ConvertAttributeTypeToSelectionField_18(id0); }

  private native void SetQueryString_19(String id0);
  public void SetQueryString(String id0)
    { SetQueryString_19(id0); }

  private native String GetQueryString_20();
  public String GetQueryString()
    { return GetQueryString_20(); }

  private native long EPSILON_21();
  public vtkInformationDoubleKey EPSILON() {
    long temp = EPSILON_21();

    if (temp == 0) return null;
    return (vtkInformationDoubleKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long CONTAINING_CELLS_22();
  public vtkInformationIntegerKey CONTAINING_CELLS() {
    long temp = CONTAINING_CELLS_22();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long COMPONENT_NUMBER_23();
  public vtkInformationIntegerKey COMPONENT_NUMBER() {
    long temp = COMPONENT_NUMBER_23();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INVERSE_24();
  public vtkInformationIntegerKey INVERSE() {
    long temp = INVERSE_24();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PIXEL_COUNT_25();
  public vtkInformationIntegerKey PIXEL_COUNT() {
    long temp = PIXEL_COUNT_25();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long SOURCE_26();
  public vtkInformationObjectBaseKey SOURCE() {
    long temp = SOURCE_26();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long SOURCE_ID_27();
  public vtkInformationIntegerKey SOURCE_ID() {
    long temp = SOURCE_ID_27();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PROP_28();
  public vtkInformationObjectBaseKey PROP() {
    long temp = PROP_28();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PROP_ID_29();
  public vtkInformationIntegerKey PROP_ID() {
    long temp = PROP_ID_29();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PROCESS_ID_30();
  public vtkInformationIntegerKey PROCESS_ID() {
    long temp = PROCESS_ID_30();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long COMPOSITE_INDEX_31();
  public vtkInformationIntegerKey COMPOSITE_INDEX() {
    long temp = COMPOSITE_INDEX_31();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long HIERARCHICAL_LEVEL_32();
  public vtkInformationIntegerKey HIERARCHICAL_LEVEL() {
    long temp = HIERARCHICAL_LEVEL_32();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long HIERARCHICAL_INDEX_33();
  public vtkInformationIntegerKey HIERARCHICAL_INDEX() {
    long temp = HIERARCHICAL_INDEX_33();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INDEXED_VERTICES_34();
  public vtkInformationIntegerKey INDEXED_VERTICES() {
    long temp = INDEXED_VERTICES_34();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void UnionSelectionList_35(vtkSelectionNode id0);
  public void UnionSelectionList(vtkSelectionNode id0)
    { UnionSelectionList_35(id0); }

  private native void SubtractSelectionList_36(vtkSelectionNode id0);
  public void SubtractSelectionList(vtkSelectionNode id0)
    { SubtractSelectionList_36(id0); }

  private native boolean EqualProperties_37(vtkSelectionNode id0,boolean id1);
  public boolean EqualProperties(vtkSelectionNode id0,boolean id1)
    { return EqualProperties_37(id0,id1); }

  public vtkSelectionNode() { super(); }

  public vtkSelectionNode(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkSelectionNode.java <==
// java wrapper for vtkSelectionNode object
//

package vtk;
import vtk.*;

public class vtkSelectionNode extends vtkObject
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void Initialize_2();
  public void Initialize()
    { Initialize_2(); }

  private native void SetSelectionList_3(vtkAbstractArray id0);
  public void SetSelectionList(vtkAbstractArray id0)
    { SetSelectionList_3(id0); }

  private native long GetSelectionList_4();
  public vtkAbstractArray GetSelectionList() {
    long temp = GetSelectionList_4();

    if (temp == 0) return null;
    return (vtkAbstractArray)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetSelectionData_5(vtkDataSetAttributes id0);
  public void SetSelectionData(vtkDataSetAttributes id0)
    { SetSelectionData_5(id0); }

  private native long GetSelectionData_6();
  public vtkDataSetAttributes GetSelectionData() {
    long temp = GetSelectionData_6();

    if (temp == 0) return null;
    return (vtkDataSetAttributes)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetProperties_7();
  public vtkInformation GetProperties() {
    long temp = GetProperties_7();

    if (temp == 0) return null;
    return (vtkInformation)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void DeepCopy_8(vtkSelectionNode id0);
  public void DeepCopy(vtkSelectionNode id0)
    { DeepCopy_8(id0); }

  private native void ShallowCopy_9(vtkSelectionNode id0);
  public void ShallowCopy(vtkSelectionNode id0)
    { ShallowCopy_9(id0); }

  private native int GetMTime_10();
  public int GetMTime()
    { return GetMTime_10(); }

  private native long CONTENT_TYPE_11();
  public vtkInformationIntegerKey CONTENT_TYPE() {
    long temp = CONTENT_TYPE_11();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetContentType_12(int id0);
  public void SetContentType(int id0)
    { SetContentType_12(id0); }

  private native int GetContentType_13();
  public int GetContentType()
    { return GetContentType_13(); }

  private native long FIELD_TYPE_14();
  public vtkInformationIntegerKey FIELD_TYPE() {
    long temp = FIELD_TYPE_14();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetFieldType_15(int id0);
  public void SetFieldType(int id0)
    { SetFieldType_15(id0); }

  private native int GetFieldType_16();
  public int GetFieldType()
    { return GetFieldType_16(); }

  private native int ConvertSelectionFieldToAttributeType_17(int id0);
  public int ConvertSelectionFieldToAttributeType(int id0)
    { return ConvertSelectionFieldToAttributeType_17(id0); }

  private native int ConvertAttributeTypeToSelectionField_18(int id0);
  public int ConvertAttributeTypeToSelectionField(int id0)
    { return ConvertAttributeTypeToSelectionField_18(id0); }

  private native void SetQueryString_19(String id0);
  public void SetQueryString(String id0)
    { SetQueryString_19(id0); }

  private native String GetQueryString_20();
  public String GetQueryString()
    { return GetQueryString_20(); }

  private native long EPSILON_21();
  public vtkInformationDoubleKey EPSILON() {
    long temp = EPSILON_21();

    if (temp == 0) return null;
    return (vtkInformationDoubleKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long ZBUFFER_VALUE_22();
  public vtkInformationDoubleKey ZBUFFER_VALUE() {
    long temp = ZBUFFER_VALUE_22();

    if (temp == 0) return null;
    return (vtkInformationDoubleKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long CONTAINING_CELLS_23();
  public vtkInformationIntegerKey CONTAINING_CELLS() {
    long temp = CONTAINING_CELLS_23();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long COMPONENT_NUMBER_24();
  public vtkInformationIntegerKey COMPONENT_NUMBER() {
    long temp = COMPONENT_NUMBER_24();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INVERSE_25();
  public vtkInformationIntegerKey INVERSE() {
    long temp = INVERSE_25();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PIXEL_COUNT_26();
  public vtkInformationIntegerKey PIXEL_COUNT() {
    long temp = PIXEL_COUNT_26();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long SOURCE_27();
  public vtkInformationObjectBaseKey SOURCE() {
    long temp = SOURCE_27();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long SOURCE_ID_28();
  public vtkInformationIntegerKey SOURCE_ID() {
    long temp = SOURCE_ID_28();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PROP_29();
  public vtkInformationObjectBaseKey PROP() {
    long temp = PROP_29();

    if (temp == 0) return null;
    return (vtkInformationObjectBaseKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PROP_ID_30();
  public vtkInformationIntegerKey PROP_ID() {
    long temp = PROP_ID_30();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long PROCESS_ID_31();
  public vtkInformationIntegerKey PROCESS_ID() {
    long temp = PROCESS_ID_31();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long COMPOSITE_INDEX_32();
  public vtkInformationIntegerKey COMPOSITE_INDEX() {
    long temp = COMPOSITE_INDEX_32();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long HIERARCHICAL_LEVEL_33();
  public vtkInformationIntegerKey HIERARCHICAL_LEVEL() {
    long temp = HIERARCHICAL_LEVEL_33();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long HIERARCHICAL_INDEX_34();
  public vtkInformationIntegerKey HIERARCHICAL_INDEX() {
    long temp = HIERARCHICAL_INDEX_34();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long INDEXED_VERTICES_35();
  public vtkInformationIntegerKey INDEXED_VERTICES() {
    long temp = INDEXED_VERTICES_35();

    if (temp == 0) return null;
    return (vtkInformationIntegerKey)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void UnionSelectionList_36(vtkSelectionNode id0);
  public void UnionSelectionList(vtkSelectionNode id0)
    { UnionSelectionList_36(id0); }

  private native void SubtractSelectionList_37(vtkSelectionNode id0);
  public void SubtractSelectionList(vtkSelectionNode id0)
    { SubtractSelectionList_37(id0); }

  private native boolean EqualProperties_38(vtkSelectionNode id0,boolean id1);
  public boolean EqualProperties(vtkSelectionNode id0,boolean id1)
    { return EqualProperties_38(id0,id1); }

  public vtkSelectionNode() { super(); }

  public vtkSelectionNode(long id) { super(id); }
  public native long   VTKInit();

}
